@@ -1,6 +1,6 @@
 package Mojolicious::Command::credentials;
-$Mojolicious::Command::credentials::VERSION = '0.003';
-use Mojo::Base 'Mojolicious::Command';
+$Mojolicious::Command::credentials::VERSION = '0.004';
+use Mojo::Base 'Mojolicious::Command', -signatures;
 
 use File::Slurper qw/read_binary write_binary/;
 use File::Temp 'tempfile';
@@ -12,8 +12,7 @@ has description => 'Edit the applications credentials';
 
 has usage => sub { shift->extract_usage };
 
-sub run {
-	my ($self, $command, @args) = @_;
+sub run($self, $command, @args) {
 	die $self->usage unless defined $command;
 
 	my $credentials = $self->app->credentials;
@@ -66,7 +65,7 @@ Mojolicious::Command::credentials - Manage your app's credentials
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
