@@ -1,28 +1,12 @@
 package Mojolicious::Plugin::Credentials;
-$Mojolicious::Plugin::Credentials::VERSION = '0.003';
-use strict;
-use warnings;
-
-use Mojo::Base 'Mojolicious::Plugin';
+$Mojolicious::Plugin::Credentials::VERSION = '0.004';
+use Mojo::Base 'Mojolicious::Plugin', -signatures;
 
 use Carp 'croak';
 use Crypt::Credentials 0.002;
 use File::Spec::Functions 'catdir';
 
-sub _get_dir {
-	my ($self, $config) = @_;
-
-	if ($config->{dir}) {
-		return $config->{dir};
-	} else {
-		my $home = Mojo::Home->new;
-		$home->detect;
-		return catdir($home->to_string, 'credentials');
-	}
-}
-
-sub _get_keys {
-	my ($self, $config) = @_;
+sub _get_keys($self, $config) {
 	if ($config->{keys}) {
 		return @{ $config->{keys} };
 	} elsif (defined $ENV{MOJO_CREDENTIALS_KEY}) {
@@ -33,10 +17,8 @@ sub _get_keys {
 	}
 }
 
-sub register {
-	my ($self, $app, $config) = @_;
-
-	my $dir  = $self->_get_dir($config);
+sub register($self, $app, $config) {
+	my $dir  = $config->{dir} // $ENV{MOJO_CREDENTIALS_DIR} // catdir($app->home, 'credentials');
 	my @keys = $self->_get_keys($config);
 
 	my $credentials = Crypt::Credentials->new(dir => $dir, keys => \@keys);
@@ -62,27 +44,29 @@ Mojolicious::Plugin::Credentials - A credentials store in mojo
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
  # Mojolicious::Lite
 
- plugin 'Credentials';
+ plugin Credentials => { keys => \@keys };
+
+ my ($password) = app->credentials->get('google');
 
  # Mojolicious
 
  sub startup {
    my $self = shift;
 
-   $self->plugin('Credentials');
+   $self->plugin(Credentials => { keys => \@keys });
  }
 
 =head1 DESCRIPTION
 
 This module plugs L<Crypt::Credentials|Crypt::Credentials> into your Mojolicious application. This allows you to store credentials using only one key.
 
-Credentials can by edited using the credentials mojo command (e.g. C<./myapp.pl credentials edit google>.
+Credentials can by edited using the credentials mojo command (e.g. C<./myapp.pl credentials edit google>).
 
 =head1 CONFIGURATION
 
@@ -94,9 +78,11 @@ It takes two arguments, both optional.
 
 This is the key used to encrypt the credentials. If not given this will use the environmental variable C<MOJO_CREDENTIALS_KEYS> (split on colons), and otherwise it will bail out. In both cases the key will be expected in hexadecimal form.
 
+Multiple keys are supported to aid key rotation, one would typically add the new key to the injected list, switch the store to the new key and only then remove the old key from the injection.
+
 =item * dir
 
-This is the directory of the credentials. If not given it will default to C<$MOJO_HOME/credentials>, or if C<MOJO_HOME> isn't defined C<./credentials>.
+This is the directory of the credentials. If not given it will default to C<$MOJO_CREDENTIALS_DIR> or if that isn't defined C<$MOJO_HOME/credentials>.
 
 =back
 
